@@ -27,6 +27,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                             {
@@ -42,6 +43,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                         ],
@@ -72,6 +74,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                             {
@@ -87,6 +90,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                             {
@@ -102,6 +106,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                         ],
@@ -139,6 +144,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                             {
@@ -154,6 +160,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                             {
@@ -169,6 +176,7 @@ class MockCMLServer(object):
                                 "ram": None,
                                 "data_volume": None,
                                 "boot_disk_size": None,
+                                "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                                 "tags": [],
                             },
                         ],
@@ -557,7 +565,7 @@ class MockCMLServer(object):
 
     @staticmethod
     def get_sys_info(req, ctx):
-        response = {"version": "2.3.0", "ready": True}
+        response = {"version": "2.4.0+build.3", "ready": True}
         return response
 
     @staticmethod
@@ -634,6 +642,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -652,6 +661,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -670,6 +680,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -683,13 +694,16 @@ class MockCMLServer(object):
                 {"id": "i4", "node": "n1", "data": {"label": "donotuse2", "slot": 2, "state": "STARTED", "type": "physical"}},
                 {"id": "i5", "node": "n1", "data": {"label": "GigabitEthernet0/0/0/0", "slot": 3, "state": "STARTED", "type": "physical"}},
             ],
-            "lab_notes": "",
-            "lab_title": "Mock Test",
-            "lab_description": "",
-            "state": "STARTED",
-            "created_timestamp": 1597805276.8213837,
-            "cluster_id": "cluster_1",
-            "version": "0.0.3",
+            "lab": {
+                "notes": "",
+                "title": "Mock Test",
+                "description": "",
+                "owner": "admin",
+                "state": "STARTED",
+                "created_timestamp": 1597805276.8213837,
+                "cluster_id": "cluster_1",
+                "version": "0.0.3",
+            },
         }
         return response
 
@@ -712,6 +726,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -730,6 +745,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -747,13 +763,16 @@ class MockCMLServer(object):
                 {"id": "i8", "node": "n1", "data": {"label": "donotuse2", "slot": 2, "state": "STOPPED", "type": "physical"}},
                 {"id": "i9", "node": "n1", "data": {"label": "GigabitEthernet0/0/0/0", "slot": 3, "state": "STOPPED", "type": "physical"}},
             ],
-            "lab_notes": "",
-            "lab_title": "Other Lab",
-            "lab_description": "",
-            "state": "STOPPED",
-            "created_timestamp": 1595337039.0416706,
-            "cluster_id": "cluster_1",
-            "version": "0.0.3",
+            "lab": {
+                "notes": "",
+                "title": "Other Lab",
+                "description": "",
+                "owner": "admin",
+                "state": "STOPPED",
+                "created_timestamp": 1595337039.0416706,
+                "cluster_id": "cluster_1",
+                "version": "0.0.3",
+            },
         }
         return response
 
@@ -776,6 +795,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -794,6 +814,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -812,6 +833,7 @@ class MockCMLServer(object):
                         "cpu_limit": None,
                         "data_volume": None,
                         "boot_disk_size": None,
+                        "compute_id": "17e91b4e-865a-4627-a6bb-50e3dfa988ab",
                         "tags": [],
                     },
                 },
@@ -856,12 +878,15 @@ class MockCMLServer(object):
                     "data": {"label": "GigabitEthernet0/0/0/0", "slot": 3, "state": "STARTED", "type": "physical"},
                 },
             ],
-            "lab_notes": "",
-            "lab_title": "Mock Test 2.3",
-            "lab_description": "",
-            "state": "STARTED",
-            "created_timestamp": 1597805276.8213837,
-            "cluster_id": "cluster_1",
-            "version": "0.0.3",
+            "lab": {
+                "notes": "",
+                "title": "Mock Test 2.3",
+                "description": "",
+                "owner": "admin",
+                "state": "STARTED",
+                "created_timestamp": 1597805276.8213837,
+                "cluster_id": "cluster_1",
+                "version": "0.0.3",
+            },
         }
         return response
